[telepathy-qt4/master] Renamed FileTransfer to FileTransferChannel.

Andre Moreira Magalhaes (andrunko) andre.magalhaes at collabora.co.uk
Wed Jul 22 22:12:09 PDT 2009


---
 TelepathyQt4/FileTransfer                          |   13 ---------
 TelepathyQt4/FileTransferChannel                   |   13 +++++++++
 TelepathyQt4/Makefile.am                           |    8 +++---
 TelepathyQt4/channel-factory.cpp                   |    4 +-
 ...file-transfer.cpp => file-transfer-channel.cpp} |   28 ++++++++++----------
 .../{file-transfer.h => file-transfer-channel.h}   |   16 +++++-----
 TelepathyQt4/types.h                               |    4 +-
 7 files changed, 43 insertions(+), 43 deletions(-)
 delete mode 100644 TelepathyQt4/FileTransfer
 create mode 100644 TelepathyQt4/FileTransferChannel
 rename TelepathyQt4/{file-transfer.cpp => file-transfer-channel.cpp} (70%)
 rename TelepathyQt4/{file-transfer.h => file-transfer-channel.h} (72%)

diff --git a/TelepathyQt4/FileTransfer b/TelepathyQt4/FileTransfer
deleted file mode 100644
index fe7675b..0000000
--- a/TelepathyQt4/FileTransfer
+++ /dev/null
@@ -1,13 +0,0 @@
-#ifndef _TelepathyQt4_Client_FileTransfer_HEADER_GUARD_
-#define _TelepathyQt4_Client_FileTransfer_HEADER_GUARD_
-
-#ifndef IN_TELEPATHY_QT4_HEADER
-#define IN_TELEPATHY_QT4_HEADER
-#endif
-
-#include <TelepathyQt4/file-transfer.h>
-
-#undef IN_TELEPATHY_QT4_HEADER
-
-#endif
-// vim:set ft=cpp:
diff --git a/TelepathyQt4/FileTransferChannel b/TelepathyQt4/FileTransferChannel
new file mode 100644
index 0000000..8554983
--- /dev/null
+++ b/TelepathyQt4/FileTransferChannel
@@ -0,0 +1,13 @@
+#ifndef _TelepathyQt4_Client_FileTransferChannel_HEADER_GUARD_
+#define _TelepathyQt4_Client_FileTransferChannel_HEADER_GUARD_
+
+#ifndef IN_TELEPATHY_QT4_HEADER
+#define IN_TELEPATHY_QT4_HEADER
+#endif
+
+#include <TelepathyQt4/file-transfer-channel.h>
+
+#undef IN_TELEPATHY_QT4_HEADER
+
+#endif
+// vim:set ft=cpp:
diff --git a/TelepathyQt4/Makefile.am b/TelepathyQt4/Makefile.am
index 879fd59..78c8281 100644
--- a/TelepathyQt4/Makefile.am
+++ b/TelepathyQt4/Makefile.am
@@ -72,7 +72,7 @@ libtelepathy_qt4_la_SOURCES = \
     debug.cpp \
     debug-internal.h \
     feature.cpp \
-    file-transfer.cpp \
+    file-transfer-channel.cpp \
     key-file.cpp \
     manager-file.cpp \
     media-session-handler.cpp \
@@ -143,7 +143,7 @@ nodist_libtelepathy_qt4_la_SOURCES = \
     _gen/contact.moc.hpp \
     _gen/contact-manager.moc.hpp \
     _gen/dbus-proxy.moc.hpp \
-    _gen/file-transfer.moc.hpp \
+    _gen/file-transfer-channel.moc.hpp \
     _gen/pending-account.moc.hpp \
     _gen/pending-channel.moc.hpp \
     _gen/pending-channel-request.moc.hpp \
@@ -184,7 +184,7 @@ tpqt4include_HEADERS = \
     DBus \
     DBusProxy \
     Feature \
-    FileTransfer \
+    FileTransferChannel \
     KeyFile \
     ManagerFile \
     MediaSessionHandler \
@@ -278,7 +278,7 @@ tpqt4include_HEADERS = \
     dbus-proxy.h \
     debug.h \
     feature.h \
-    file-transfer.h \
+    file-transfer-channel.h \
     key-file.h \
     manager-file.h \
     media-session-handler.h \
diff --git a/TelepathyQt4/channel-factory.cpp b/TelepathyQt4/channel-factory.cpp
index 9a356cb..8d430f4 100644
--- a/TelepathyQt4/channel-factory.cpp
+++ b/TelepathyQt4/channel-factory.cpp
@@ -24,7 +24,7 @@
 #include <TelepathyQt4/Channel>
 #include <TelepathyQt4/Connection>
 #include <TelepathyQt4/Constants>
-#include <TelepathyQt4/FileTransfer>
+#include <TelepathyQt4/FileTransferChannel>
 #include <TelepathyQt4/RoomListChannel>
 #include <TelepathyQt4/StreamedMediaChannel>
 #include <TelepathyQt4/TextChannel>
@@ -54,7 +54,7 @@ ChannelPtr ChannelFactory::create(const ConnectionPtr &connection,
     }
     else if (channelType == TELEPATHY_INTERFACE_CHANNEL_TYPE_FILE_TRANSFER) {
         return ChannelPtr(dynamic_cast<Channel*>(
-                    FileTransfer::create(connection,
+                    FileTransferChannel::create(connection,
                         channelPath, immutableProperties).data()));
     }
 
diff --git a/TelepathyQt4/types.h b/TelepathyQt4/types.h
index 92160f4..ada4322 100644
--- a/TelepathyQt4/types.h
+++ b/TelepathyQt4/types.h
@@ -44,7 +44,7 @@ class ClientObject;
 class ClientRegistrar;
 class Connection;
 class ConnectionManager;
-class FileTransfer;
+class FileTransferChannel;
 class RoomListChannel;
 class MediaStream;
 class StreamedMediaChannel;
@@ -60,7 +60,7 @@ typedef SharedPtr<ClientObject> ClientObjectPtr;
 typedef SharedPtr<ClientRegistrar> ClientRegistrarPtr;
 typedef SharedPtr<Connection> ConnectionPtr;
 typedef SharedPtr<ConnectionManager> ConnectionManagerPtr;
-typedef SharedPtr<FileTransfer> FileTransferPtr;
+typedef SharedPtr<FileTransferChannel> FileTransferChannelPtr;
 typedef SharedPtr<RoomListChannel> RoomListChannelPtr;
 typedef SharedPtr<MediaStream> MediaStreamPtr;
 typedef SharedPtr<StreamedMediaChannel> StreamedMediaChannelPtr;
diff --git a/TelepathyQt4/file-transfer.cpp b/TelepathyQt4/file-transfer-channel.cpp
similarity index 70%
rename from TelepathyQt4/file-transfer.cpp
rename to TelepathyQt4/file-transfer-channel.cpp
index 7c975b5..5edd469 100644
--- a/TelepathyQt4/file-transfer.cpp
+++ b/TelepathyQt4/file-transfer-channel.cpp
@@ -1,4 +1,4 @@
 /* FileTransfer channel client-side proxy
  *
  * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
  * Copyright (C) 2009 Nokia Corporation
@@ -18,9 +18,9 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <TelepathyQt4/FileTransfer>
+#include <TelepathyQt4/FileTransferChannel>
 
-#include "TelepathyQt4/_gen/file-transfer.moc.hpp"
+#include "TelepathyQt4/_gen/file-transfer-channel.moc.hpp"
 #include "TelepathyQt4/debug-internal.h"
 
 #include <TelepathyQt4/Connection>
@@ -28,24 +28,24 @@
 namespace Tp
 {
 
-struct FileTransfer::Private
+struct FileTransferChannel::Private
 {
     inline Private();
     inline ~Private();
 };
 
-FileTransfer::Private::Private()
+FileTransferChannel::Private::Private()
 {
 }
 
-FileTransfer::Private::~Private()
+FileTransferChannel::Private::~Private()
 {
 }
 
 /**
- * \class FileTransfer
+ * \class FileTransferChannel
  * \ingroup clientchannel
- * \headerfile TelepathyQt4/file-transfer.h <TelepathyQt4/FileTransfer>
+ * \headerfile TelepathyQt4/file-transfer-channel.h <TelepathyQt4/FileTransferChannel>
  *
  * High-level proxy object for accessing remote %Channel objects of the
  * FileTransfer channel type. These channels can be used to transfer one file
@@ -55,25 +55,25 @@ FileTransfer::Private::~Private()
  * FileTransfer interface. Until then, it's just a Channel.
  */
 
-FileTransferPtr FileTransfer::create(const ConnectionPtr &connection,
+FileTransferChannelPtr FileTransferChannel::create(const ConnectionPtr &connection,
         const QString &objectPath, const QVariantMap &immutableProperties)
 {
-    return FileTransferPtr(new FileTransfer(connection, objectPath,
+    return FileTransferChannelPtr(new FileTransferChannel(connection, objectPath,
                 immutableProperties));
 }
 
 /**
  * Creates a FileTransfer associated with the given object on the same service
  * as the given connection.
  *
  * \param connection  Connection owning this FileTransfer, and specifying the
  *                    service.
  * \param objectPath  Path to the object on the service.
  * \param immutableProperties  The immutable properties of the channel, as
  *                             signalled by NewChannels or returned by
  *                             CreateChannel or EnsureChannel
  */
-FileTransfer::FileTransfer(const ConnectionPtr &connection,
+FileTransferChannel::FileTransferChannel(const ConnectionPtr &connection,
         const QString &objectPath,
         const QVariantMap &immutableProperties)
     : Channel(connection, objectPath, immutableProperties),
@@ -84,7 +84,7 @@ FileTransfer::FileTransfer(const ConnectionPtr &connection,
 /**
  * Class destructor.
  */
-FileTransfer::~FileTransfer()
+FileTransferChannel::~FileTransferChannel()
 {
     delete mPriv;
 }
@@ -1,4 +1,4 @@
-/* FileTransfer channel client-side proxy
+/* FileTransferChannel channel client-side proxy
  *
  * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
@@ -55,25 +55,25 @@ FileTransfer::Private::~Private()
 
 /**
- * Creates a FileTransfer associated with the given object on the same service
+ * Creates a FileTransferChannel associated with the given object on the same service
  * as the given connection.
  *
@@ -55,25 +55,25 @@ FileTransfer::Private::~Private()
  * as the given connection.
  *
- * \param connection  Connection owning this FileTransfer, and specifying the
+ * \param connection  Connection owning this FileTransferChannel, and specifying the
  *                    service.
  * \param objectPath  Path to the object on the service.
diff --git a/TelepathyQt4/file-transfer.h b/TelepathyQt4/file-transfer-channel.h
similarity index 72%
rename from TelepathyQt4/file-transfer.h
rename to TelepathyQt4/file-transfer-channel.h
index ada7330..0598ee3 100644
--- a/TelepathyQt4/file-transfer.h
+++ b/TelepathyQt4/file-transfer-channel.h
@@ -1,4 +1,4 @@
 /* FileTransfer channel client-side proxy
  *
  * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
  * Copyright (C) 2009 Nokia Corporation
@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef _TelepathyQt4_Client_file_transfer_h_HEADER_GUARD_
-#define _TelepathyQt4_Client_file_transfer_h_HEADER_GUARD_
+#ifndef _TelepathyQt4_Client_file_transfer_channel_h_HEADER_GUARD_
+#define _TelepathyQt4_Client_file_transfer_channel_h_HEADER_GUARD_
 
 #ifndef IN_TELEPATHY_QT4_HEADER
 #error IN_TELEPATHY_QT4_HEADER
@@ -30,19 +30,19 @@
 namespace Tp
 {
 
-class FileTransfer : public Channel
+class FileTransferChannel : public Channel
 {
     Q_OBJECT
-    Q_DISABLE_COPY(FileTransfer)
+    Q_DISABLE_COPY(FileTransferChannel)
 
 public:
-    static FileTransferPtr create(const ConnectionPtr &connection,
+    static FileTransferChannelPtr create(const ConnectionPtr &connection,
             const QString &objectPath, const QVariantMap &immutableProperties);
 
-    virtual ~FileTransfer();
+    virtual ~FileTransferChannel();
 
 protected:
-    FileTransfer(const ConnectionPtr &connection, const QString &objectPath,
+    FileTransferChannel(const ConnectionPtr &connection, const QString &objectPath,
             const QVariantMap &immutableProperties);
 
 private:
@@ -1,4 +1,4 @@
-/* FileTransfer channel client-side proxy
+/* FileTransferChannel channel client-side proxy
  *
  * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
-- 
1.5.6.5




More information about the telepathy-commits mailing list